import { Observable } from '../Observable';
import { Subscriber } from '../Subscriber';
import { tryCatch } from '../util/tryCatch';
import { errorObject } from '../util/errorObject';
import { bindCallback } from '../util/bindCallback';
export function skipWhile(predicate, thisArg) {
    return this.lift(new SkipWhileOperator(predicate, thisArg));
}
class SkipWhileOperator {
    constructor(predicate, thisArg) {
        this.predicate = bindCallback(predicate, thisArg, 2);
    }
    call(subscriber) {
        return new SkipWhileSubscriber(subscriber, this.predicate);
    }
}
class SkipWhileSubscriber extends Subscriber {
    constructor(destination, predicate) {
        super(destination);
        this.predicate = predicate;
        this.skipping = true;
        this.index = 0;
    }
    _next(value) {
        const destination = this.destination;
        if (this.skipping === true) {
            const index = this.index++;
            const result = tryCatch(this.predicate)(value, index);
            if (result === errorObject) {
                destination.error(result.e);
            }
            else {
                this.skipping = Boolean(result);
            }
        }
        if (this.skipping === false) {
            destination.next(value);
        }
    }
}
Observable.prototype.skipWhile = skipWhile;
//# sourceMappingURL=skipWhile.js.map