import { Observable } from '../Observable';
import { Subscriber } from '../Subscriber';
import { tryCatch } from '../util/tryCatch';
import { errorObject } from '../util/errorObject';
import { bindCallback } from '../util/bindCallback';
export function takeWhile(predicate, thisArg) {
    return this.lift(new TakeWhileOperator(predicate, thisArg));
}
class TakeWhileOperator {
    constructor(predicate, thisArg) {
        this.predicate = predicate;
        this.thisArg = thisArg;
    }
    call(subscriber) {
        return new TakeWhileSubscriber(subscriber, this.predicate, this.thisArg);
    }
}
class TakeWhileSubscriber extends Subscriber {
    constructor(destination, predicate, thisArg) {
        super(destination);
        this.index = 0;
        if (typeof predicate === 'function') {
            this.predicate = bindCallback(predicate, thisArg, 2);
        }
    }
    _next(value) {
        const destination = this.destination;
        const result = tryCatch(this.predicate)(value, this.index++);
        if (result == errorObject) {
            destination.error(result.e);
        }
        else if (Boolean(result)) {
            destination.next(value);
        }
        else {
            destination.complete();
        }
    }
}
Observable.prototype.takeWhile = takeWhile;
//# sourceMappingURL=takeWhile.js.map